@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.cpp 2280 2006-12-18 14:21:07Z svn $
+ * $Id: UploaderConfig.cpp 2285 2006-12-22 00:53:58Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -46,7 +46,7 @@
 #include "Message.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploaderConfig.cpp 2280 2006-12-18 14:21:07Z svn $");
+SOURCE_INFO_ADD("$Id: UploaderConfig.cpp 2285 2006-12-22 00:53:58Z svn $");
 
 #define PARAM_PREFIX "Uploader"
 
@@ -233,18 +233,15 @@ void UploaderConfig::set_template(template_type_t type, const char *tmpl_file_pa
 
 const char *UploaderConfig::to_string(apr_pool_t *pool)
 {
-    return apr_pstrcat(pool,
-                       apr_psprintf(pool, "%-18s : %s\n",
-                                    "base_url", base_url),
-                       apr_psprintf(pool, "%-18s : %s\n",
-                                    "data_dir_path", data_dir_path),
-                       apr_psprintf(pool, "%-18s : %s\n",
-                                    "file_dir_path", file_dir_path),
-                       apr_psprintf(pool, "%-18s : %s\n",
-                                    "thumb_dir_path", thumb_dir_path),
-                       apr_psprintf(pool, "%-18s : %s\n",
-                                    "temp_dir_path", temp_dir_path),
-                       NULL);
+    return apr_pstrcat
+        (pool,
+         "* UploaderConfig:\n",
+         self_to_string(pool),
+         "* PostFlowController:\n",
+         PostFlowController::dump_list(pool, post_flow_controller_),
+         "* DownloadFlowController:\n",
+         DownloadFlowController::dump_list(pool, download_flow_controller_),
+         NULL);
 }
 
 
@@ -285,6 +282,24 @@ void UploaderConfig::update_template(template_type_t type)
     tmpls_[type]->update();
 }
 
+const char *UploaderConfig::self_to_string(apr_pool_t *pool)
+{
+    return apr_pstrcat
+        (pool,
+         apr_psprintf(pool, "%-24s : %s\n",
+                      "base_url", base_url),
+         apr_psprintf(pool, "%-24s : %s\n",
+                      "data_dir_path", data_dir_path),
+         apr_psprintf(pool, "%-24s : %s\n",
+                      "file_dir_path", file_dir_path),
+         apr_psprintf(pool, "%-24s : %s\n",
+                      "thumb_dir_path", thumb_dir_path),
+         apr_psprintf(pool, "%-24s : %s\n",
+                      "temp_dir_path", temp_dir_path),
+
+                       NULL);
+}
+
 // Local Variables:
 // mode: c++
 // coding: utf-8-dos
