@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_handler.cpp 2296 2006-12-24 02:58:57Z svn $
+ * $Id: uploader_handler.cpp 2368 2007-01-13 09:48:03Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -56,7 +56,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2296 2006-12-24 02:58:57Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2368 2007-01-13 09:48:03Z svn $");
 #endif
 
 #define IS_REQUEST_COMMAND(arg, command) \
@@ -411,7 +411,9 @@ static int upload_impl(typename Response::Handle *r, UploaderConfig *config,
     regist_post(config, Response::get_remote_addr(r));
 
     Response::set_env(r, "uploader_upload", "");
-    Response::set_env(r, "uploader_item_id", apr_itoa(r->pool, item_id));
+    Response::set_env(r, "uploader_item_id",
+                      apr_psprintf(r->pool,
+                                   "%" APR_SIZE_T_FMT, item_id));
 
     return redirect<Response>
         (r, o, apr_pstrcat(r->pool, config->base_url, ARG_SEPARATE_STR, NULL));
@@ -448,7 +450,7 @@ static int upload(typename Response::Handle *r, UploaderConfig *config,
         return error<Response>(r, config, MESSAGE_POST_INTERVAL_TOO_SHORT);
     }
 
-    upload_id = static_cast<apr_size_t>
+    upload_id = static_cast<apr_uint32_t>
         (apr_atoi64(get_word(r->pool, &arg, ARG_SEPARATE_STR[0])));
 
     progress = config->get_post_progress_list()->add(upload_id);
@@ -499,7 +501,7 @@ static int progress_data(typename Response::Handle *r, UploaderConfig *config,
     apr_uint32_t upload_id;
     RequestReader::post_progress_t *progress;
 
-    upload_id = static_cast<apr_size_t>
+    upload_id = static_cast<apr_uint32_t>
         (apr_atoi64(get_word(r->pool, &arg, ARG_SEPARATE_STR[0])));
 
     typename Response::Writer o(r);
@@ -714,9 +716,16 @@ static int download(typename Response::Handle *r, UploaderConfig *config,
             Response::set_accept_ranges(r);
 
             dispos_encoding = get_dispos_encoding(Response::get_user_agent(r));
+
+#ifdef NUMNAME
+            file_name = apr_psprintf(r->pool, "%s%" APR_SIZE_T_FMT ".%s",
+                                     NUMNAME, uitem->get_index(),
+                                     uitem->get_file_ext());
+#else
             file_name = CharCodeConverter::convert
                 (r->pool, uitem->get_file_name(),
                  CharCodeConverter::DEFAULT_CODE, dispos_encoding);
+#endif
 
             // 表示モード or ダウンロードモード
             open_mode = (strlen(get_word(r->pool, &arg,
@@ -729,7 +738,9 @@ static int download(typename Response::Handle *r, UploaderConfig *config,
                               file_name));
 
             Response::set_env(r, "uploader_download", "");
-            Response::set_env(r, "uploader_item_id", apr_itoa(r->pool, item_id));
+            Response::set_env(r, "uploader_item_id",
+                              apr_psprintf(r->pool,
+                                           "%" APR_SIZE_T_FMT, item_id));
 
             Response::Writer::sendfile(r, item_file, uitem->get_file_size());
             finish_download(config, Response::get_remote_addr(r));
@@ -800,7 +811,8 @@ static int remove(typename Response::Handle *r, UploaderConfig *config,
         } else {
             Response::set_env(r, "uploader_remove", "");
             Response::set_env(r, "uploader_item_id",
-                              apr_itoa(r->pool, item_id));
+                              apr_psprintf(r->pool,
+                                           "%" APR_SIZE_T_FMT, item_id));
 
             return redirect<Response>
                 (r, o,
